@@ -19,23 +19,18 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import absolute_import
 
-import six
+class _UndefinedCore:
+    name = None
 
-moves = [
-    six.MovedAttribute("getoutput", "commands", "subprocess"),
-]
 
-for m in moves:
-    six.add_move(m)
+class _UndefinedQtile:
+    core = _UndefinedCore()
 
-# Here, we can't use six.Moved* methods because being able to import asyncio vs
-# trollius is not strictly Py 2 vs Py 3, but rather asyncio for >=3.4, and
-# possibly 3.3 with Tulip, and trollius for 2 and <=3.2, and 3.3 without Tulip.
-# We can no longer direct assign to six.moves, so let's just leave it here so
-# we don't need to keep try/except importing asyncio.
-try:
-    import asyncio  # noqa
-except ImportError:
-    import trollius as asyncio  # noqa
+
+qtile = _UndefinedQtile()
+
+
+def init(q):
+    global qtile
+    qtile = q
