@@ -38,6 +38,7 @@ import typing
 import cairocffi
 
 from libqtile import pangocffi, utils
+from libqtile.log_utils import logger
 
 if typing.TYPE_CHECKING:
     from libqtile.backend.base import Internal
@@ -375,8 +376,7 @@ class TextLayout:
         layout.set_alignment(pangocffi.ALIGN_CENTER)
         if not wrap:  # pango wraps by default
             layout.set_ellipsize(pangocffi.ELLIPSIZE_END)
-        desc = pangocffi.FontDescription.from_string(font_family)
-        desc.set_absolute_size(pangocffi.units_from_double(float(font_size)))
+        desc = pangocffi.FontDescription.from_string(f"{font_family} {font_size}px")
         layout.set_font_description(desc)
         self.font_shadow = font_shadow
         self.layout = layout
@@ -387,9 +387,6 @@ class TextLayout:
     def finalize(self):
         self.layout.finalize()
 
-    def finalized(self):
-        self.layout.finalized()
-
     @property
     def text(self):
         return self.layout.get_text()
@@ -400,8 +397,11 @@ class TextLayout:
             # pangocffi doesn't like None here, so we use "".
             if value is None:
                 value = ""
-            attrlist, value, accel_char = pangocffi.parse_markup(value)
-            self.layout.set_attributes(attrlist)
+            try:
+                attrlist, value, accel_char = pangocffi.parse_markup(value)
+                self.layout.set_attributes(attrlist)
+            except pangocffi.BadMarkup as e:
+                logger.warning(e)
         self.layout.set_text(utils.scrub_to_utf8(value))
 
     @property
@@ -416,8 +416,7 @@ class TextLayout:
         self._width = value
         self.layout.set_width(pangocffi.units_from_double(value))
 
-    @width.deleter
-    def width(self):
+    def reset_width(self):
         self._width = None
         self.layout.set_width(-1)
 
@@ -442,12 +441,11 @@ class TextLayout:
     @property
     def font_size(self):
         d = self.fontdescription()
-        return d.get_size()
+        return pangocffi.units_to_double(int(d.get_size()))
 
     @font_size.setter
     def font_size(self, size):
         d = self.fontdescription()
-        d.set_size(size)
         d.set_absolute_size(pangocffi.units_from_double(size))
         self.layout.set_font_description(d)
 
