@@ -24,16 +24,40 @@
 # is annoying, so we ignore libqtile/layout/__init__.py completely
 # flake8: noqa
 
-from .stack import Stack
-from .max import Max
-from .xmonad import MonadTall
-from .tile import Tile
-from .floating import Floating
-from .ratiotile import RatioTile
-from .slice import Slice
-from .tree import TreeTab
-from .zoomy import Zoomy
-from .matrix import Matrix
-from .verticaltile import VerticalTile
-from .wmii import Wmii
-from .columns import Columns
+__all__ = [
+    "Bsp",
+    "Columns",
+    "Floating",
+    "Matrix",
+    "Max",
+    "Plasma",
+    "RatioTile",
+    "ScreenSplit",
+    "Slice",
+    "Spiral",
+    "Stack",
+    "Tile",
+    "TreeTab",
+    "VerticalTile",
+    "MonadTall",
+    "MonadThreeCol",
+    "MonadWide",
+    "Zoomy",
+]
+
+from libqtile.layout.bsp import Bsp
+from libqtile.layout.columns import Columns
+from libqtile.layout.floating import Floating
+from libqtile.layout.matrix import Matrix
+from libqtile.layout.max import Max
+from libqtile.layout.plasma import Plasma
+from libqtile.layout.ratiotile import RatioTile
+from libqtile.layout.screensplit import ScreenSplit
+from libqtile.layout.slice import Slice
+from libqtile.layout.spiral import Spiral
+from libqtile.layout.stack import Stack
+from libqtile.layout.tile import Tile
+from libqtile.layout.tree import TreeTab
+from libqtile.layout.verticaltile import VerticalTile
+from libqtile.layout.xmonad import MonadTall, MonadThreeCol, MonadWide
+from libqtile.layout.zoomy import Zoomy
