@@ -41,7 +41,6 @@ widgets = {
     "Countdown": "countdown",
     "CryptoTicker": "crypto_ticker",
     "CurrentLayout": "currentlayout",
-    "CurrentLayoutIcon": "currentlayout",
     "CurrentScreen": "currentscreen",
     "DF": "df",
     "DoNotDisturb": "do_not_disturb",
@@ -70,6 +69,7 @@ widgets = {
     "Mpris2": "mpris2widget",
     "Net": "net",
     "NetGraph": "graph",
+    "NetUP": "netup",
     "Notify": "notify",
     "NvidiaSensors": "nvidia_sensors",
     "OpenWeather": "open_weather",
