@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2011 Kenji_Takahashi
 # Copyright (c) 2011 Mounier Florian
 # Copyright (c) 2012, 2014 Tycho Andersen
@@ -23,13 +22,19 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from . import base
 from subprocess import call
 
+from libqtile.widget import base
+
+
+class Canto(base.ThreadPoolText):
+    """Display RSS feeds updates using the canto console reader
+
+    Widget requirements: canto_
+
+    .. _canto: https://codezen.org/canto-ng/
+    """
 
-class Canto(base.ThreadedPollText):
-    """Display RSS feeds updates using the canto console reader"""
-    orientations = base.ORIENTATION_HORIZONTAL
     defaults = [
         ("fetch", False, "Whether to fetch new items on update"),
         ("feeds", [], "List of feeds to display, empty for all"),
@@ -38,7 +43,7 @@ class Canto(base.ThreadedPollText):
     ]
 
     def __init__(self, **config):
-        base.ThreadedPollText.__init__(self, **config)
+        base.ThreadPoolText.__init__(self, "", **config)
         self.add_defaults(Canto.defaults)
 
     def poll(self):
@@ -46,14 +51,16 @@ class Canto(base.ThreadedPollText):
             arg = "-a"
             if self.fetch:
                 arg += "u"
-            output = self.all_format.format(
-                number=self.call_process(["canto", arg])[:-1]
-            )
+            output = self.all_format.format(number=self.call_process(["canto", arg])[:-1])
             return output
         else:
             if self.fetch:
                 call(["canto", "-u"])
-            return "".join([self.one_format.format(
-                name=feed,
-                number=self.call_process(["canto", "-n", feed])[:-1]
-            ) for feed in self.feeds])
+            return "".join(
+                [
+                    self.one_format.format(
+                        name=feed, number=self.call_process(["canto", "-n", feed])[:-1]
+                    )
+                    for feed in self.feeds
+                ]
+            )
