@@ -21,9 +21,7 @@
 
 from libqtile import config
 
-keys = [
-    config.Key(["control"], "k", "focusnext")
-]
+keys = [config.Key(["control"], "k", "focusnext")]
 
 screens = []
 layouts = []
