@@ -2,6 +2,7 @@
 # Copyright (c) 2012, 2014 Tycho Andersen
 # Copyright (c) 2013 Craig Barnes
 # Copyright (c) 2014 Sean Vig
+# Copyright (c) 2021 elParaguayo
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,7 +21,7 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-import logging
+import asyncio
 
 import pytest
 
@@ -30,11 +31,14 @@ import libqtile.confreader
 import libqtile.layout
 import libqtile.log_utils
 import libqtile.widget
-from libqtile.command.base import CommandObject
-from libqtile.command.interface import CommandError
+from libqtile.command.base import CommandObject, expose_command
+from libqtile.command.client import CommandClient
+from libqtile.command.interface import CommandError, IPCCommandInterface
 from libqtile.confreader import Config
+from libqtile.ipc import Client, IPCError
 from libqtile.lazy import lazy
 from test.conftest import dualmonitor
+from test.helpers import Retry
 
 
 class CallConfig(Config):
@@ -65,6 +69,7 @@ class CallConfig(Config):
             bottom=libqtile.bar.Bar(
                 [
                     libqtile.widget.GroupBox(),
+                    libqtile.widget.TextBox(),
                 ],
                 20,
             ),
@@ -80,25 +85,56 @@ call_config = pytest.mark.parametrize("manager", [CallConfig], indirect=True)
 def test_layout_filter(manager):
     manager.test_window("one")
     manager.test_window("two")
-    assert manager.c.groups()["a"]["focus"] == "two"
+    assert manager.c.get_groups()["a"]["focus"] == "two"
     manager.c.simulate_keypress(["control"], "j")
-    assert manager.c.groups()["a"]["focus"] == "one"
+    assert manager.c.get_groups()["a"]["focus"] == "one"
     manager.c.simulate_keypress(["control"], "k")
-    assert manager.c.groups()["a"]["focus"] == "two"
+    assert manager.c.get_groups()["a"]["focus"] == "two"
 
 
-class TestCommands(CommandObject):
+@call_config
+def test_param_hoisting(manager):
+    manager.test_window("two")
+
+    client = Client(manager.sockfile)
+    command = IPCCommandInterface(client)
+    cmd_client = CommandClient(command)
+
+    # 'zomg' is not a valid warp command
+    with pytest.raises(IPCError):
+        cmd_client.navigate("window", None).call("focus", warp="zomg", lifted=True)
+
+    cmd_client.navigate("window", None).call("focus", warp=False, lifted=True)
+
+    # 'zomg' is not a valid bar position
+    with pytest.raises(IPCError):
+        cmd_client.call("hide_show_bar", position="zomg", lifted=True)
+
+    cmd_client.call("hide_show_bar", position="top", lifted=True)
+
+    # 'zomg' is not a valid font size
+    with pytest.raises(IPCError):
+        cmd_client.navigate("widget", "textbox").call("set_font", fontsize="zomg", lifted=True)
+
+    cmd_client.navigate("widget", "textbox").call("set_font", fontsize=12, lifted=True)
+
+
+class FakeCommandObject(CommandObject):
     @staticmethod
-    def cmd_one():
+    @expose_command()
+    def one():
         pass
 
-    def cmd_one_self(self):
+    @expose_command()
+    def one_self(self):
         pass
 
-    def cmd_two(self, a):
+    @expose_command()
+    def two(self, a):
         pass
 
-    def cmd_three(self, a, b=99):
+    @expose_command()
+    def three(self, a, b=99):
         pass
 
     def _items(self, name):
@@ -109,24 +145,30 @@ class TestCommands(CommandObject):
 
 
 def test_doc():
-    c = TestCommands()
-    assert "one()" in c.cmd_doc("one")
-    assert "one_self()" in c.cmd_doc("one_self")
-    assert "two(a)" in c.cmd_doc("two")
-    assert "three(a, b=99)" in c.cmd_doc("three")
+    c = FakeCommandObject()
+    assert "one()" in c.doc("one")
+    assert "one_self()" in c.doc("one_self")
+    assert "two(a)" in c.doc("two")
+    assert "three(a, b=99)" in c.doc("three")
 
 
 def test_commands():
-    c = TestCommands()
-    assert len(c.cmd_commands()) == 9
+    c = FakeCommandObject()
+    assert len(c.commands()) == 9
 
 
 def test_command():
-    c = TestCommands()
+    c = FakeCommandObject()
     assert c.command("one")
     assert not c.command("nonexistent")
 
 
+class DecoratedTextBox(libqtile.widget.TextBox):
+    @expose_command("mapped")
+    def exposed(self):
+        return "OK"
+
+
 class ServerConfig(Config):
     auto_fullscreen = True
     keys = []
@@ -154,7 +196,7 @@ class ServerConfig(Config):
         libqtile.config.Screen(
             bottom=libqtile.bar.Bar(
                 [
-                    libqtile.widget.TextBox(name="two"),
+                    DecoratedTextBox(name="two"),
                 ],
                 20,
             ),
@@ -393,7 +435,6 @@ def test_core_node(manager, backend_name):
 
 
 def test_lazy_arguments(manager_nospawn):
-
     # Decorated function to be bound to key presses
     @lazy.function
     def test_func(qtile, value, multiplier=1):
@@ -420,51 +461,60 @@ def test_lazy_arguments(manager_nospawn):
     assert val == "500"
 
 
-def test_deprecated_modules(caplog):
-    libqtile.log_utils.init_log()
+def test_lazy_function_coroutine(manager_nospawn):
+    """Test that lazy.function accepts coroutines."""
 
-    from libqtile.command_client import InteractiveCommandClient  # noqa: F401
+    @Retry(ignore_exceptions=(AssertionError,))
+    def assert_func_text(manager, value):
+        _, text = manager.c.eval("self.test_func_output")
+        assert text == value
 
-    assert caplog.record_tuples == [
-        (
-            "libqtile",
-            logging.WARNING,
-            "libqtile.command_client is deprecated. It has been moved to libqtile.command.client",
-        )
-    ]
+    @lazy.function
+    async def test_async_func(qtile, value):
+        await asyncio.sleep(0.1)
+        qtile.test_func_output = value
 
-    caplog.clear()
+    config = ServerConfig
+    config.keys = [libqtile.config.Key(["control"], "k", test_async_func("qtile"))]
 
-    from libqtile.command_graph import CommandGraphNode  # noqa: F401
+    manager_nospawn.start(config)
 
-    assert caplog.record_tuples == [
-        (
-            "libqtile",
-            logging.WARNING,
-            "libqtile.command_graph is deprecated. It has been moved to libqtile.command.graph",
-        )
-    ]
+    manager_nospawn.c.simulate_keypress(["control"], "k")
+    assert_func_text(manager_nospawn, "qtile")
 
-    caplog.clear()
 
-    from libqtile.command_interface import CommandInterface  # noqa: F401
+def test_decorators_direct_call():
+    widget = DecoratedTextBox()
+    undecorated = libqtile.widget.TextBox()
 
-    assert caplog.record_tuples == [
-        (
-            "libqtile",
-            logging.WARNING,
-            "libqtile.command_interface is deprecated. It has been moved to libqtile.command.interface",
-        )
-    ]
+    cmds = ["exposed", "mapped"]
 
-    caplog.clear()
+    for cmd in cmds:
+        # Check new command is exposed
+        assert cmd in widget.commands()
+        # Check commands are not in widget with same parent class
+        assert cmd not in undecorated.commands()
 
-    from libqtile.command_object import CommandObject  # noqa: F401
+    assert widget.exposed() == "OK"
+    assert widget.mapped() == "OK"
 
-    assert caplog.record_tuples == [
-        (
-            "libqtile",
-            logging.WARNING,
-            "libqtile.command_object is deprecated. It has been moved to libqtile.command.base.",
-        )
-    ]
+
+def test_decorators_deprecated_direct_call():
+    widget = DecoratedTextBox()
+    assert widget.cmd_exposed() == "OK"
+
+
+def test_decorators_deprecated_method():
+    class CmdWidget(libqtile.widget.TextBox):
+        def cmd_exposed(self):
+            pass
+
+    assert "exposed" in CmdWidget().commands()
+
+
+@dualmonitor
+@server_config
+def test_decorators_manager_call(manager):
+    widget = manager.c.widget["two"]
+    assert widget.exposed() == "OK"
+    assert widget.mapped() == "OK"
