@@ -18,6 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import json
 import os
 import re
 import subprocess
@@ -28,11 +29,17 @@ import libqtile.bar
 import libqtile.config
 import libqtile.layout
 import libqtile.widget
+from libqtile.command.base import expose_command
 from libqtile.confreader import Config
 from libqtile.lazy import lazy
 
 
 class ServerConfig(Config):
+    class KwargWidget(libqtile.widget.base._TextBox):
+        @expose_command
+        def test_kwargs(self, *, a: int = 0):
+            return {"value": a}
+
     auto_fullscreen = True
     keys = [
         libqtile.config.Key(["mod4"], "Return", lazy.spawn("xterm")),
@@ -69,9 +76,7 @@ class ServerConfig(Config):
     screens = [
         libqtile.config.Screen(
             bottom=libqtile.bar.Bar(
-                [
-                    libqtile.widget.TextBox(name="one"),
-                ],
+                [libqtile.widget.TextBox(name="one"), KwargWidget("")],
                 20,
             ),
         ),
@@ -89,16 +94,18 @@ class ServerConfig(Config):
 server_config = pytest.mark.parametrize("manager", [ServerConfig], indirect=True)
 
 
-def run_qtile_cmd(args, no_eval=False):
+def run_qtile_cmd(args, no_json_loads=False):
     cmd = os.path.join(os.path.dirname(__file__), "..", "bin", "qtile")
     argv = [cmd, "cmd-obj"]
     argv.extend(args.split())
     pipe = subprocess.Popen(argv, stdout=subprocess.PIPE)
     output, _ = pipe.communicate()
     output = output.decode()
-    if no_eval:
+    if not output:
+        return False
+    if no_json_loads:
         return output
-    return eval(output)  # as returned by pprint.pprint
+    return json.loads(output)
 
 
 @server_config
@@ -166,4 +173,15 @@ def test_cmd_obj_root_node(manager):
     cmd_no_root = base
     cmd_with_root = f"{base} -o root"
 
-    assert run_qtile_cmd(cmd_no_root, no_eval=True) == run_qtile_cmd(cmd_with_root, no_eval=True)
+    assert run_qtile_cmd(cmd_no_root, no_json_loads=True) == run_qtile_cmd(
+        cmd_with_root, no_json_loads=True
+    )
+
+
+@server_config
+def test_cmd_obj_kwarg(manager):
+    cmd = f"-s {manager.sockfile} -o widget kwargwidget -f test_kwargs -k a=2"
+    result = run_qtile_cmd(cmd)
+
+    # This confirms that value has correctly been converted to int
+    assert result["value"] == 2
