@@ -84,32 +84,32 @@ def test_chord_widget(fake_window, fake_qtile):
 
     # Chord is in chords_colors so check colours
     assert chord.background == RED
-    assert chord.foreground == BLUE
+    assert chord.layout.colour == BLUE
     assert chord.text == "testcolor"
 
     # New chord, not in dictionary so should be default colours
     hook.fire("enter_chord", "test")
     assert chord.text == "test"
     assert chord.background == BASE_BACKGROUND
-    assert chord.foreground == BASE_FOREGROUND
+    assert chord.layout.colour == BASE_FOREGROUND
 
     # Unnamed chord so no text
     hook.fire("enter_chord", "")
     assert chord.text == ""
     assert chord.background == BASE_BACKGROUND
-    assert chord.foreground == BASE_FOREGROUND
+    assert chord.layout.colour == BASE_FOREGROUND
 
     # Back into testcolor and custom colours
     hook.fire("enter_chord", "testcolor")
     assert chord.background == RED
-    assert chord.foreground == BLUE
+    assert chord.layout.colour == BLUE
     assert chord.text == "testcolor"
 
     # Colours shoud reset when leaving chord
     hook.fire("leave_chord")
     assert chord.text == ""
     assert chord.background == BASE_BACKGROUND
-    assert chord.foreground == BASE_FOREGROUND
+    assert chord.layout.colour == BASE_FOREGROUND
 
     # Finalize the widget to prevent segfault (the drawer needs to be finalised)
     # We clear the _futures attribute as there are no real timers in it and calls
