@@ -30,13 +30,8 @@ from libqtile.confreader import Config
 
 class WindowNameConfig(Config):
     auto_fullscreen = True
-    groups = [
-        libqtile.config.Group("a"),
-        libqtile.config.Group("b")
-    ]
-    layouts = [
-        layout.Max()
-    ]
+    groups = [libqtile.config.Group("a"), libqtile.config.Group("b")]
+    layouts = [layout.Max()]
     floating_layout = libqtile.resources.default_config.floating_layout
     keys = []
     mouse = []
@@ -48,7 +43,10 @@ class WindowNameConfig(Config):
                 ],
                 24,
             ),
-            x=0, y=0, width=900, height=480
+            x=0,
+            y=0,
+            width=900,
+            height=480,
         ),
         Screen(
             top=bar.Bar(
@@ -57,9 +55,11 @@ class WindowNameConfig(Config):
                 ],
                 24,
             ),
-            x=0, y=480, width=900, height=480
+            x=0,
+            y=480,
+            width=900,
+            height=480,
         ),
-
     ]
     screens = []
 
@@ -69,7 +69,6 @@ windowname_config = pytest.mark.parametrize("manager", [WindowNameConfig], indir
 
 @windowname_config
 def test_window_names(manager):
-
     def widget_text_on_screen(index):
         return manager.c.screen[index].bar["top"].info()["widgets"][0]["text"]
 
@@ -80,7 +79,7 @@ def test_window_names(manager):
     assert widget_text_on_screen(0) == widget_text_on_screen(1)
 
     # Load a window
-    proc = manager.test_window('one')
+    proc = manager.test_window("one")
     assert widget_text_on_screen(0) == "one"
     assert widget_text_on_screen(0) == widget_text_on_screen(1)
 
@@ -107,7 +106,7 @@ def test_window_names(manager):
 
     # Quick test to check for_current_screen=False works
     manager.c.to_screen(1)
-    proc = manager.test_window('one')
+    proc = manager.test_window("one")
     assert widget_text_on_screen(0) == " "
     assert widget_text_on_screen(1) == "one"
     manager.kill_window(proc)
